============
Installation
============

At the command line::

    $ easy_install poshsplice

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv poshsplice
    $ pip install poshsplice
